import { Request, Response } from "express";
import prisma from "../../database/dbclient";


export const GetDesignationCount = async (req: Request, res: Response) => {
    try {
        const { page = 1, limit = 10 } = req.query;

        // Convert page and limit to numbers
        const pageNumber = parseInt(page as string, 10);
        const limitNumber = parseInt(limit as string, 10);

        // Calculate the offset (skip) for pagination
        const offset = (pageNumber - 1) * limitNumber;

        // Fetch companies with pagination
        const companies = await prisma.companies.findMany({
            skip: offset,
            take: limitNumber,
            orderBy: {
                created_at: 'desc',
            },
            include: {
                designations: true, 
            },
        });

        // Fetch total count of companies
        const totalCompanies = await prisma.companies.count();

        // Calculate total pages
        const totalPages = Math.ceil(totalCompanies / limitNumber);

        // Format companies data to include the number of designations
        const formattedCompanies = companies.map(company => ({
            ...company,
            totalDesignations: company.designations.length,  // Count of designations for the company
        }));

        // Return paginated response
        return res.status(200).json({
            companies: formattedCompanies,
            totalCompanies,
            totalPages,
            currentPage: pageNumber,
            limit: limitNumber,
        });
    } catch (error) {
        console.error('Error fetching companies:', error);
        return res.status(500).json({ message: 'An error occurred while fetching companies' });
    }
};